@@ -1,6 +1,6 @@
 /* canonusr.c - user canonicalization support
  * Rob Siemborski
- * $Id: canonusr.c,v 1.10 2002/09/16 18:37:20 rjs3 Exp $
+ * $Id: canonusr.c,v 1.11 2002/12/05 04:26:20 rjs3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -303,15 +303,18 @@ static int _canonuser_internal(const sasl_utils_t *utils,
 	u_apprealm = strlen(sconn->user_realm) + 1;
     }
     
-    /* Now copy! (FIXME: check for SASL_BUFOVER?) */
+    /* Now Copy */
     memcpy(out_user, begin_u, MIN(ulen, out_umax));
     if(sconn && u_apprealm) {
+	if(ulen >= out_umax) return SASL_BUFOVER;
 	out_user[ulen] = '@';
 	memcpy(&(out_user[ulen+1]), sconn->user_realm,
 	       MIN(u_apprealm-1, out_umax-ulen-1));
     }
     out_user[MIN(ulen + u_apprealm,out_umax)] = '\0';
 
+    if(ulen + u_apprealm > out_umax) return SASL_BUFOVER;
+
     if(out_ulen) *out_ulen = MIN(ulen + u_apprealm,out_umax);
     
     sasl_FREE(in_buf);
