@@ -1,6 +1,6 @@
 /* OTP SASL plugin
  * Ken Murchison
- * $Id: otp.c,v 1.24 2002/10/13 23:51:04 ken3 Exp $
+ * $Id: otp.c,v 1.26 2002/12/11 19:34:33 ken3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -54,6 +54,7 @@
 #include <assert.h>
 
 #include <openssl/evp.h>
+#include <openssl/md5.h> /* XXX hack for OpenBSD/OpenSSL cruftiness */
 
 #include <sasl.h>
 #define MD5_H  /* suppress internal MD5 */
@@ -73,7 +74,7 @@
 
 /*****************************  Common Section  *****************************/
 
-static const char plugin_id[] = "$Id: otp.c,v 1.24 2002/10/13 23:51:04 ken3 Exp $";
+static const char plugin_id[] = "$Id: otp.c,v 1.26 2002/12/11 19:34:33 ken3 Exp $";
 
 #define OTP_SEQUENCE_MAX	9999
 #define OTP_SEQUENCE_DEFAULT	499
@@ -1733,7 +1734,8 @@ static sasl_client_plug_t otp_client_plugins[] =
 	SASL_SEC_NOPLAINTEXT
 	| SASL_SEC_NOANONYMOUS
 	| SASL_SEC_FORWARD_SECRECY,	/* security_flags */
-	SASL_FEAT_WANT_CLIENT_FIRST,	/* features */
+	SASL_FEAT_WANT_CLIENT_FIRST
+	| SASL_FEAT_ALLOWS_PROXY,	/* features */
 	NULL,				/* required_prompts */
 	NULL,				/* glob_context */
 	&otp_client_mech_new,		/* mech_new */
